require "faraday"
require "faraday_middleware"

module AfTalk
  class Connection
    URL = "https://api.africastalking.com".freeze
    SANDBOX_URL = "https://api.sandbox.africastalking.com".freeze

    def self.build
      @_connection ||= new.build
    end

    def self.clear
      @_connection = nil
    end

    def build
      Faraday.new(
        url: api_url,
        headers: { apiKey: AfTalk::Configuration.api_key,
                   accept: "application/json" },
      ) do |connection|
        connection.request :url_encoded
        connection.response :json,
                            content_type: /\bjson$/,
                            parser_options: { symbolize_names: true }
        connection.adapter Faraday.default_adapter
      end
    end

    private

    def api_url
      ENV["AFRICAS_TALKING_SANDBOX"] ? SANDBOX_URL : URL
    end
  end
end
